from django.shortcuts import render, redirect, get_object_or_404
from django.http import HttpResponse, HttpResponseForbidden
from django.contrib.auth.decorators import login_required
from .models import UnitOfMeasure
from django.contrib import messages
from django.db import IntegrityError

@login_required
def uoms(request):
    if request.user.is_admin_user or request.user.is_super_user or request.user.is_inventory:
        try:
            uoms = UnitOfMeasure.objects.all()
            return render(request, "inventory/uom/uoms.html", {'uoms': uoms})
        except Exception as e:
            messages.error(request, f"An error occurred: {str(e)}")
            return redirect('inventory:uoms')
    else:
        return HttpResponseForbidden("You are not authorized to view this page.")

@login_required
def add_uom(request):
    if request.user.is_admin_user or request.user.is_super_user or request.user.is_inventory:
        if request.method == 'POST':
            try:
                symbol = request.POST.get('symbol')
                unit = request.POST.get('unit')
                added_by = request.user
                uom = UnitOfMeasure(symbol=symbol, unit=unit, added_by=added_by)
                uom.save()
                messages.success(request, 'Unit of Measure added successfully.')
                return redirect("inventory:uoms")
            except IntegrityError as e:
                messages.error(request, f"Data integrity error: {str(e)}")
            except Exception as e:
                messages.error(request, f"An error occurred: {str(e)}")
        return render(request, "inventory/uom/add_uom.html")
    else:
        return HttpResponseForbidden("You are not authorized to view this page.")

@login_required
def edit_uom(request, uom_id):
    if request.user.is_admin_user or request.user.is_super_user or request.user.is_inventory:
        try:
            uom = get_object_or_404(UnitOfMeasure, id=uom_id)
            if request.method == 'POST':
                symbol = request.POST.get('symbol')
                unit = request.POST.get('unit')
                uom.symbol = symbol
                uom.unit = unit
                uom.save()
                messages.success(request, 'Unit of Measure updated successfully.')
                return redirect("inventory:uoms")
            return render(request, "inventory/uom/edit_uom.html", {'uom': uom})
        except IntegrityError as e:
            messages.error(request, f"Data integrity error: {str(e)}")
            return redirect('inventory:uoms')
        except Exception as e:
            messages.error(request, f"An error occurred: {str(e)}")
            return redirect('inventory:uoms')
    else:
        return HttpResponseForbidden("You are not authorized to view this page.")

@login_required
def delete_uom(request, uom_id):
    if request.user.is_admin_user or request.user.is_super_user or request.user.is_inventory:
        try:
            uom = get_object_or_404(UnitOfMeasure, id=uom_id)
            uom_unit = uom.unit
            uom.delete()
            messages.success(request, f"Unit of Measure '{uom_unit}' has been deleted successfully.")
        except Exception as e:
            messages.error(request, f"An error occurred while deleting the Unit of Measure: {str(e)}")
        return redirect("inventory:uoms")
    else:
        return HttpResponseForbidden("You are not authorized to view this page.")